@@ -59,6 +59,7 @@ LANGUAGES = (('.R','R'),
             ('.sh','sh'),
             ('.tcl','tcl'),
             ('texinfo','texinfo'),
+            ('.txt','None'),
             ('.vb','vbnet'),
             ('verilog','verilog'),
             ('vhdl','vhdl'),
@@ -181,10 +182,10 @@ class Window(hildon.Window):
     return 'python'
     
   def _detect_language(self,filepath):
-    
+        
     if filepath==None:
       return self.prefs.prefs_dict['default_language']
-            
+                  
     for extension,lang in LANGUAGES:
       if filepath.endswith(extension.lower()):
         return lang
@@ -408,7 +409,7 @@ class Window(hildon.Window):
       self._parent.create_window() 
     elif label=='Recent':
       filepath = pge_recentchooser.Dialog().get()
-      if path!=None:
+      if filepath!=None:
         self._parent.create_window(filepath)
 #       fc = gtk.RecentChooserDialog("Recent Documents", self, None,(gtk.STOCK_OPEN, gtk.RESPONSE_ACCEPT))
 #       if fc.run()==gtk.RESPONSE_ACCEPT:                                    
